==> wfde-3.01.10.tar.gz: wfde-3.01.10/cpplib/WarException.cpp <==
#include "StdAfx.h"
#include "WarException.h"   // class implemented
#ifndef WAR_ITOA_H
#   include "WarItoa.h"
#endif

using namespace std;

/////////////////////////////// PUBLIC ///////////////////////////////////////

//============================= LIFECYCLE ====================================

WarException::WarException(const war_error_definitions local_error,
                           const int system_error,
                           war_ccstr_t message,
                           war_ccstr_t source_file,
                           const int source_line)
                           : WarError(local_error, system_error, 
                                source_file, source_line),
                           mMessage(message)
{
}// WarException

WarException::WarException(const WarException& from)
: WarError(from),
mMessage(from.mMessage)
{
}// WarException

WarException::WarException(const WarError& err,
                           war_ccstr_t message)
                           : WarError(err),
                           mMessage(message)
{
}

WarException::~WarException()
{
}// ~WarException


//============================= OPERATORS ====================================
//============================= OPERATIONS ===================================

std::string WarException::Explain() const
{
    string msg = "Exception from ", tmp_str;
    msg += GetFile();
    msg += " line ";
    msg += WarItoa(tmp_str, GetLine());
    msg += " caused by ";
    msg += WarError::Explain();

    return msg;
}

//============================= ACESS      ===================================
//============================= INQUIRY    ===================================
/////////////////////////////// PROTECTED  ///////////////////////////////////

/////////////////////////////// PRIVATE    ///////////////////////////////////

==> wfde-3.01.11.tar.gz: wfde-3.01.11/cpplib/WarException.cpp <==
#include "StdAfx.h"
#include "WarException.h"   // class implemented
#ifndef WAR_ITOA_H
#   include "WarItoa.h"
#endif

using namespace std;

/////////////////////////////// PUBLIC ///////////////////////////////////////

//============================= LIFECYCLE ====================================

WarException::WarException(const war_error_definitions local_error,
                           const int system_error,
                           war_ccstr_t message,
                           war_ccstr_t source_file,
                           const int source_line)
                           : WarError(local_error, system_error, 
                                source_file, source_line),
                                mMessage(message ? message : "")
{
}// WarException

WarException::WarException(const WarException& from)
: WarError(from),
mMessage(from.mMessage)
{
}// WarException

WarException::WarException(const WarError& err,
                           war_ccstr_t message)
                           : WarError(err),
                           mMessage(message ? message : "")
{
}

WarException::~WarException()
{
}// ~WarException


//============================= OPERATORS ====================================
//============================= OPERATIONS ===================================

const std::string& WarException::Explain() const
{
    if (mMessageBuf.empty())
    {
        std::string msg, tmp_str;
        msg = "Exception from ";
        msg += GetFile();
        msg += " line ";
        msg += WarItoa(tmp_str, GetLine());
        msg += " caused by ";
        msg += WarError::Explain();
        if (!msg.empty())
        {
            msg += " [";
            msg += mMessage;
            msg += ']';
        }

        (std::string &)mMessageBuf = msg;
    }

    return mMessageBuf;
}

const char *WarException::what() const throw()
{
    return Explain().c_str();
}

//============================= ACESS      ===================================
//============================= INQUIRY    ===================================
/////////////////////////////// PROTECTED  ///////////////////////////////////

/////////////////////////////// PRIVATE    ///////////////////////////////////
